==> haskell-skylighting-format-ansi-0.1-260-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-4Xd2liHEbSPCVWVPXpN4Lz
key:                  skylighting-format-ansi-0.1-4Xd2liHEbSPCVWVPXpN4Lz
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  be319d1a7a19de867b8b3ff6f9d7d9e1
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-4Xd2liHEbSPCVWVPXpN4Lz
depends:
    ansi-terminal-1.0.2-K3FcB9OuSW9G9IWrQwwwo4 base-4.17.2.1
    binary-0.8.9.1 colour-2.3.6-5TQtDkpBL6qIeyTKm1JGVg containers-0.6.7
    skylighting-core-0.14.2-DB3Bg6HHgy674FCTp1eWcE text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-ansi-0.1-280-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-ansi
version:              0.1
visibility:           public
id:                   skylighting-format-ansi-0.1-GyTxq5IIj0T4GNjUVSEcju
key:                  skylighting-format-ansi-0.1-GyTxq5IIj0T4GNjUVSEcju
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             ANSI formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as ANSI colored text.

category:             Text
abi:                  17672d7e819fe3fe2e76a384868b4449
exposed:              True
exposed-modules:      Skylighting.Format.ANSI
import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-format-ansi-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-ansi
hs-libraries:         HSskylighting-format-ansi-0.1-GyTxq5IIj0T4GNjUVSEcju
depends:
    ansi-terminal-1.0.2-HSq0v3QUl8T11Wgx1QLnTe base-4.17.2.1
    binary-0.8.9.1 colour-2.3.6-Es9wrqLKeClLAeJW79jO2p containers-0.6.7
    skylighting-core-0.14.3-3942VFqpxT92bo8sB6TPZ4 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-ansi/html/skylighting-format-ansi.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-ansi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
